import { Book, Copy, Repository } from '@/payload-types'
import { getPayload, PaginatedDocs } from 'payload'
import configPromise from '@payload-config'
import BookByIdPageClient from './page.client'

type Params = Promise<{ bookId: string }>
type SearchParams = Promise<{ [key: string]: string | undefined }>

type Props = {
  params: Params
  searchParams: SearchParams
}
const BookByIdPage = async (props: Props) => {
  const params = await props.params

  const bookIdFromUrl = parseInt(params?.bookId || '', 10)
  if (Number.isNaN(bookIdFromUrl)) return null
  const bookId = bookIdFromUrl as number

  const payload = await getPayload({ config: configPromise })

  const defaultRepositoryLimit = 10

  const foundBook = (await payload.findByID({
    collection: 'books',
    depth: 3,
    overrideAccess: false,
    id: bookId,
    select: {
      title: true,
      authors: true,
      publication: true,
      lcc: true,
      genre: true,
      isbn: true,
      copies: true,
      summary: true,
      description: true,
    },
  })) as Book

  const repositoryIds = foundBook.copies?.docs?.map((c) => (c as Copy).repository)

  const orQueries = repositoryIds?.map((c) => {
    return {
      id: {
        equals: c,
      },
    }
  })

  const repositories = (await payload.find({
    collection: 'repositories',
    depth: 3,
    limit: defaultRepositoryLimit,
    select: {
      id: true,
      owners: true,
      abbreviation: true,
      name: true,
    },
    where: {
      or: orQueries?.length ? orQueries : [],
    },
  })) as PaginatedDocs<Repository>

  return <BookByIdPageClient book={foundBook} repositories={repositories} />
}

export default BookByIdPage
