import { defaultAccess } from '@/lib/utils'
import type { CollectionConfig } from 'payload'

export const Users: CollectionConfig = {
  slug: 'users',
  admin: {
    useAsTitle: 'email',
  },
  auth: true,
  access: {
    ...defaultAccess,
    update: ({ req, data }) => {
      if (req.user?.role === 'admin') return true
      else if (data?.user.id === req.user?.id) return true
      else return false
    }
  },
  fields: [
    // Email added by default
    // Add more fields as needed
    {
      name: 'role',
      type: 'select',
      options: ['admin', 'user', 'unclaimed'],
      saveToJWT: true
    },
    {
      name: 'firstName',
      type: 'text',
    },
    {
      name: 'lastName',
      type: 'text',
    },
    {
      name: 'isOwnershipClaimed',
      type: 'checkbox',
    },
    {
      name: 'repositories',
      type: 'join',
      collection: 'repositories',
      on: 'owner',
    },
    {
      name: 'profilePicture',
      type: 'relationship',
      relationTo: 'media',
    },
  ],
}
