import { ArrowRight, Plus } from 'lucide-react'
import React from 'react'

import { Button } from '@/components/ui/button'
import { Separator } from '@/components/ui/separator'
import { PaginatedDocs } from 'payload'
import { Media, Repository } from '@/payload-types'
import Image from 'next/image'
import Link from 'next/link'

type Props = {
  repos: PaginatedDocs<Repository> | null
}

const RepoList = (props: Props) => {
  const { repos } = props

  return (
    <section className="py-6">
      <div className="mb-4 flex justify-between items-end">
        <h3 className="px-4 text-lg font-semibold">Your Repositories</h3>
        <Link
          href="/account/repos/add"
          className="flex align-middle items-center justify-around transition-all hover:scale-105"
        >
          <Plus className="inline-block size-4" />
          <span className="inline-block">Add New</span>
        </Link>
      </div>
      <Separator />
      {repos?.docs.map((item, index) => {
        const image = (item.image as Media) || undefined

        return (
          <React.Fragment key={index}>
            <div className="grid items-center px-4 py-3 sm:py-2 grid-cols-5">
              <div className="flex sm:items-center gap-2 col-span-5  sm:col-span-4">
                <span className="flex h-14 w-16 shrink-0 items-center justify-center sm:items-end">
                  <Image
                    height={26}
                    width={26}
                    alt=""
                    src={image?.url || '/images/library.svg'}
                    className="w-full items-center justify-center rounded-full bg-muted"
                  />
                </span>
                <div className="flex flex-wrap items-center justify-between sm:items-stretch sm:justify-normal sm:flex-nowrap sm:flex-col">
                  <h3 className="font-semibold">{item.name}</h3>
                  <p className="text-sm text-muted-foreground">{item.abbreviation}</p>
                  <p className="text-xs font-thin italic w-full shrink-0 sm:w-auto sm:shrink">
                    {item.dateOpenToPublic ? (
                      <span>Opened: {item.dateOpenToPublic}</span>
                    ) : (
                      <span>Not Opened to Public</span>
                    )}
                  </p>
                  <p className="pr-4 mt-1">{item.description}</p>
                </div>
              </div>
              <Button
                className="col-span-1 col-start-4 mt-2 sm:mt-0 sm:col-start-5"
                variant="outline"
                asChild
              >
                <a className="ml-auto gap-2" href={`/repo/${item.abbreviation}`}>
                  <span>View Repo</span>
                  <ArrowRight className="h-4 w-4" />
                </a>
              </Button>
            </div>
            <Separator />
          </React.Fragment>
        )
      })}
    </section>
  )
}

export default RepoList
