'use server'

import { getPayload, PaginatedDocs } from 'payload'
import config from '@/payload.config'
import { Book } from '@/payload-types'

type SearchBooksProps = {
  author?: string,
  title?: string,
}
export const searchBooks = async (props: SearchBooksProps): Promise<PaginatedDocs<Book> | null> => {
  const { author, title } = props

  const payloadConfig = await config
  const payload = await getPayload({ config: payloadConfig })

  const andQueries = []

  if (author) andQueries.push({
    'authors.fl': {
      like: author
    }
  })

  if (title) andQueries.push({
    title: {
      like: title
    }
  })

  if (!andQueries.length) return null

  const searchResponse = (await payload.find({
    collection: 'books',
    depth: 10,
    limit: 25,
    overrideAccess: false,
    where: {
      and: andQueries
    },
    select: {
      title: true,
      authors: true,
      publication: true,
      lcc: true,
      genre: true,
      isbn: true,
      copies: true,
    },
  })) as PaginatedDocs<Book>

  return searchResponse
} 
